@@ -10,6 +10,8 @@
 # --------------------------------------------------------------------------------------------------
 import time
 import redis
+from redis import Redis
+from typing import Optional
 
 
 class RedisDBPro:
@@ -25,7 +27,7 @@ class RedisDBPro:
         self._max_connections = max_connections  # 同一个redis对象使用的并发数（连接池的最大连接数），超过这个数量会抛出redis.ConnectionError
         self._kwargs = kwargs
         # 连接
-        self.__redis = None
+        self.__redis: Optional[Redis] = None
         self.get_connect()
 
     def __del__(self):
@@ -174,6 +176,34 @@ class RedisDBPro:
     def delete(self, table):
         return self._redis.delete(table)
 
+    def hset(self, table: str, key=None, value=None, mapping=None):
+        """
+            返回值：新增字段的个数（1表示新加；0表示覆盖了已有字段）
+            一次性设置多个字段：使用 mapping 参数（推荐）
+        :param table:
+        :param key:
+        :param value:
+        :param mapping:
+        :return:
+        """
+        return self._redis.hset(name=table, key=key, value=value, mapping=mapping)
+
+    def hget(self,name,key):
+        """
+            读单个
+        :param name: 表
+        :param key: key
+        :return:
+        """
+        return self._redis.hget(name,key)
+
+    def hgetall(self,name):
+        """
+            读全部字段（小 Hash 可用，大 Hash 慎用）
+        :param name:
+        :return:
+        """
+        return self._redis.hgetall(name)
 
 if __name__ == '__main__':
     pass
